plotExplore <-
function(X,pdfname=NULL,pdfwidth=11.69,pdfheight=8.27,bx.range=1.5,show.names=TRUE,cex.x=0.6,highlight=NULL,global.median=FALSE, ...){
 
  nb.arrays<-dim(X)[2]
  if (is.matrix(X)){
    X<-as.data.frame(X)
  }

  if (!is.null(pdfname)) {
    pdf(paste(pdfname,".pdf",sep=""),width=pdfwidth, height=pdfheight)
  }
  
  # Boxplots
  col<-rep(NA,nb.arrays)
  mark<-NULL
  if(!is.null(highlight)){
    mark<-match(highlight,names(X))
    if(any(is.na(mark))){
          cat("Warning",highlight[is.na(mark)]," not found") 
    }
    if(any(!is.na(mark))){
      mark<-mark[!is.na(mark)]
      col[mark]<-"red"
    }
  }
  
  boxplot(X,xlab = "Arrays", ylab = "Expression",range=bx.range,xaxt="n",col=col, ...)  
  if (show.names){
    if(is.null(mark))
      axis(side=1,at=(1:nb.arrays),las=2,cex.axis=cex.x,labels=names(X))
    else {
      axis(side=1,at=(1:nb.arrays)[-mark],las=2,cex.axis=cex.x,labels=names(X)[-mark])
      axis(side=1,at=(1:nb.arrays)[mark],las=2,cex.axis=cex.x,col.axis="red",labels=names(X)[mark])
    }
  }
  
  if (global.median){
    global.median<-median(unlist(X))
    abline(h=global.median,col="green",lwd=2)
  }
  
  # Densities plot
  if (is.null(pdfname)) {
      x11()
  }

  l<-apply(X,2,function(v){density(v,na.rm=TRUE)})
  xlim<-range(sapply(l,function(dens){range(dens$x,na.rm=TRUE)}),na.rm=TRUE)
  ylim<-range(sapply(l,function(dens){range(dens$y,na.rm=TRUE)}),na.rm=TRUE)
  plot(xlim,ylim,type="n",xlab="Expression",ylab="Density", ...)
  
  if(!is.null(mark)){
    density.plot<-sapply(l[-mark],function(dens){lines(dens,col="black", lwd=1, type="l")})
    density.plot<-sapply(l[mark],function(dens){lines(dens,col="red", lwd=1, type="l")})
  }else {   
    density.plot<-sapply(l,function(dens){lines(dens,col="black", lwd=1, type="l")})
  }
  
  if (!is.null(pdfname)) {
    dev.off()
  }
}

