\name{goReport}
\alias{goReport}

\title{Text report from the result of a call to 'hyperGTest' for GO category}
\description{
  Create a text report with the significant probesets for each significant GO category from the result of a call to 'hyperGTest'
}
\usage{
goReport(hgOver, fileout = "report.txt", type = c("CC", "MF", "BP"),
pack.annot, pvalue = 0.05, categorySize=1)
}

\arguments{
  \item{hgOver}{result from a call to 'hyperGTest'}
  \item{fileout}{name of txt file, by default "report.txt"}
  \item{type}{type of GO categories, by default = c("CC", "MF", "BP")}
  \item{pack.annot}{the annotation package to use}
  \item{pvalue}{cutoff for significant pvalue, by default 0.05}
  \item{categorySize}{integer, minimum size for category, by default = 1}
}

\value{
  Txt report with the results of a call to 'hyperGTest'
}

\author{EMA group}


\seealso{ \code{\link{hyperGTest}},\code{\link{runHyperGO}}}
\examples{
  data(marty)
  ## Probe list
  probeList <- rownames(marty)[1:50]

  ## Create an instance of a subclass of 'HyperGParams'

  designALL <- names(unlist(as.list(hgu133plus2ACCNUM)))
  entrezIds <- mget(designALL, envir = hgu133plus2ENTREZID)
  haveEntrezId <- names(entrezIds)[sapply(entrezIds, function(x) !is.na(x))]
  haveGo <- sapply(mget(haveEntrezId, hgu133plus2GO),
                   function(x) {
                     if (length(x) == 1 && is.na(x)) {
                       FALSE
                     }else {
                       TRUE
                     }
                   })

  designGO <- haveEntrezId[haveGo]
  entrezUniverse <- na.omit(unique(unlist(mget(designALL, hgu133plus2ENTREZID))))
  listGO <- intersect(probeList, designGO)
  numNoGO <- length(probeList) - length(listGO)
  selectedEntrezIds <- na.omit(unique(unlist(mget(listGO, hgu133plus2ENTREZID))))  
  params.BP.over <- new("GOHyperGParams", geneIds = selectedEntrezIds, universeGeneIds = entrezUniverse, annotation = "hgu133plus2.db", ontology = "BP", pvalueCutoff = 0.05, conditional = TRUE, testDirection = "over")
 
  ## Hypergeometric test
  hgOver.BP <- hyperGTest(params.BP.over)

  ## Report txt
  goReport(hgOver.BP, pack.annot = "hgu133plus2.db", type="BP")
}

\keyword{htest}

