\name{mult.clustering}
\alias{mult.clustering}
\title{multiple clustering}
\description{
Computes hierarchical clustering with all the metric and method pairs. Return the best clustering according to the agglomerative coefficient.
}
\usage{
mult.clustering(data, type = c("cont", "contabs", "disc", "bin"))
}

\arguments{
  \item{data}{A matrix}
  \item{type}{The type of the data. This must be one of 'cont', 'contabs', 'disc', 'bin'}
}
\details{
  The metrics tested depend on the type of data:
  \describe{
  \item{cont:}{continuous data, computes 'euclidean', 'pearson', and 'spearman' distances}
  \item{contabs:}{continuous data, computes 'euclidean', 'pearsonabs', and 'spearmanabs' distances}
  \item{disc:}{discrete data, computes 'euclidean', and 'manhattan' distances}
  \item{bin:}{0-1 data, computes 'jaccard' and 'dice' distances}
   }
  The agglomerative linkage : 'average', 'single', 'complete', 'ward'  are always tested.
}
\value{
  A list with the best clustering, and the asociated metrics
  \item{tree}{An object of class 'agnes' representing the clustering. See 'agnes.object' for details.}
  \item{met}{The metric used}
  \item{method}{The linkage used}
}

\author{EMA group}

\seealso{ \code{\link{agnes}}, \code{\link{clustering}}}
\examples{
data(marty)
data.f <- expFilter(marty, graph=FALSE)
mult.clustering(data.f, type="cont")
}
\keyword{cluster}

